@@ -2,27 +2,19 @@
 """
 -------------------------------------------------
    File Name：     global_var
-   Description :
+   Description :   用于保存全局变量
    Author :        Asdil
    date：          2020/11/5
 -------------------------------------------------
    Change Activity:
-                   2020/11/5:
+                   2022/08/03:
 -------------------------------------------------
 """
 __author__ = 'Asdil'
 
 
 def __init():
-    """__init方法用于初始化
-
-    Parameters
-    ----------
-    param : str
-
-    Returns
-    ----------
-    """
+    """__init方法用于初始化"""
     global __global_dict
     __global_dict = {}
 
@@ -62,13 +54,7 @@ def set(key, value):
 
 
 def keys():
-    """keys方法用于获取所有变量名
-
-    Parameters
-    ----------
-    Returns
-    ----------
-    """
+    """keys方法用于获取所有变量名"""
     return list(__global_dict.keys())
 
 
