@@ -12,22 +12,27 @@
 """
 __author__ = 'Asdil'
 
+
 import os
 import ast
-import subprocess
-import shutil
-import gzip
+import sys
 import math
+import shutil
+import subprocess
+from tqdm import tqdm
 import importlib.machinery
 from collections import Counter
-from tqdm import tqdm
 
 
 def bar(data):
-    """
-    进度条
-    :param data: 列表 字典 迭代器
-    :return:
+    """bar方法用于进度条
+
+    Parameters
+    ----------
+    data : int or list or dict or iterator
+
+    Returns
+    ----------
     """
     if isinstance(data, int):
         return tqdm(range(data))
@@ -35,7 +40,7 @@ def bar(data):
 
 
 def safe_eval(string):
-    """方法用于
+    """方法用于字符串转为对象
 
     Parameters
     ----------
@@ -48,7 +53,10 @@ def safe_eval(string):
     try:
         ret = ast.literal_eval(string)
     except:
-        raise ValueError(f"""错误! 无法转化语句: {string} """)
+        try:
+            ret = eval(ret)
+        except:
+            raise ValueError(f"""错误! 无法转化语句: {string} """)
     return ret
 
 
@@ -220,9 +228,9 @@ def is_type(data, typ):
 
     Parameters
     ----------
-    data : anydata
+    data : object
         任何数据
-    typ ： anytype
+    typ : object
         需要确认的数据类型
     Returns
     ----------
@@ -233,7 +241,7 @@ def is_type(data, typ):
 
 
 def sort_list(data, ind, ascending=True):
-    """sort_list方法用于
+    """sort_list方法用于排序列表，多维列表
 
     Parameters
     ----------
@@ -310,47 +318,68 @@ def get_files(path, extension=None, exclude=None, include=None):
     return ret
 
 
-def get_name(path, extension=None, key=None):
-    """
-    获取目标目录下文件名
-    :param path:      路径
-    :param extension: 后缀
-    :param key:       关键字
-    :return:
+def get_name(path, extension=None, include=None):
+    """get_name方法用于
+
+    Parameters
+    ----------
+    path : str
+        路径
+    extension : str or None
+        后缀
+    include : str or None
+        包含某个字符
+    Returns
+    ----------
     """
     if extension is not None:
         l = -len(extension)
         ret = [each for each in os.listdir(path) if each[l:] == extension]
-    elif key is not None:
-        ret = [each for each in os.listdir(path) if key in each]
+    elif include is not None:
+        ret = [each for each in os.listdir(path) if include in each]
     else:
         ret = [each for each in os.listdir(path)]
     return ret
 
 
 def subprocess_check_call(cmd):
-    """
-    执行命令行命令
-    :param cmd:  命令行命令
-    :return:
+    """subprocess_check_call方法用于执行命令行命令
+
+    Parameters
+    ----------
+    cmd : str
+        命令行命令
+
+    Returns
+    ----------
     """
     subprocess.check_call(cmd, shell=True)
 
 
 def subprocess_call(cmd):
-    """
-    执行命令行命令，不检查
-    :param cmd:  命令行命令
-    :return:
+    """subprocess_call方法用于执行命令行命令，不检查是否执行成功
+
+    Parameters
+    ----------
+    cmd : str
+        命令行命令
+
+    Returns
+    ----------
     """
     subprocess.call(cmd, shell=True)
 
 
 def subprocess_popen(cmd):
-    """
-    执行命令获取返回值
-    :param cmd:  命令行命令
-    :return:
+    """subprocess_popen方法用于执行命令获取返回值
+
+    Parameters
+    ----------
+    cmd : str
+        命令行命令
+
+    Returns
+    ----------
     """
     p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE)
     out, err = p.communicate()
@@ -361,7 +390,7 @@ def split_path(path):
     """
     拆分目录
     eg: '/tmp/tmp/a.txt'
-        '/tmp/tmp', 'a.txt', 'a', 'txt'
+        '/tmp/tmp', 'a', '.txt', 'a.txt'
     :param path: 路径
     :return:
     """
@@ -374,11 +403,17 @@ def split_path(path):
 
 
 def inter_set(l1, l2):
-    """
-    列表交集
-    :param l1:
-    :param l2:
-    :return:
+    """inter_set方法用于列表交集
+
+    Parameters
+    ----------
+    l1 : list or set or dict
+        列表或者集合
+    l2 : list or set or dict
+        列表或者集合
+
+    Returns
+    ----------
     """
     assert type(l1) in {list, set, dict}
     assert type(l2) in {list, set, dict}
@@ -389,11 +424,14 @@ def inter_set(l1, l2):
 
 
 def inter_set_num(l1, l2):
-    """inter_set_num方法用于
+    """inter_set_num方法用于找交集数量
 
     Parameters
     ----------
-    param : str
+    l1 : list or set or dict
+        列表1
+    l2 : list or set or dict
+        列表2
 
     Returns
     ----------
@@ -407,11 +445,17 @@ def inter_set_num(l1, l2):
 
 
 def diff_set(l1, l2):
-    """
-    列表差集
-    :param l1:
-    :param l2:
-    :return:
+    """diff_set方法用于找差集
+
+    Parameters
+    ----------
+    l1 : list or set or dict
+        列表1
+    l2 : list or set or dict
+        列表2
+
+    Returns
+    ----------
     """
     assert type(l1) in {list, set, dict}
     assert type(l2) in {list, set, dict}
@@ -426,7 +470,10 @@ def diff_set_num(l1, l2):
 
     Parameters
     ----------
-    param : str
+    l1 : list or set or dict
+        列表1
+    l2 : list or set or dict
+        列表2
 
     Returns
     ----------
@@ -440,11 +487,17 @@ def diff_set_num(l1, l2):
 
 
 def union_set(l1, l2):
-    """
-    列表并集
-    :param l1:
-    :param l2:
-    :return:
+    """union_set方法用于并集
+
+    Parameters
+    ----------
+    l1 : list or set or dict
+        列表1
+    l2 : list or set or dict
+        列表2
+
+    Returns
+    ----------
     """
     assert type(l1) in {list, set, dict}
     assert type(l2) in {list, set, dict}
@@ -455,11 +508,17 @@ def union_set(l1, l2):
 
 
 def union_set_num(l1, l2):
-    """
-    列表并集元素数量
-    :param l1:
-    :param l2:
-    :return:
+    """union_set_num方法用于并集数量
+
+    Parameters
+    ----------
+    l1 : list or set or dict
+        列表1
+    l2 : list or set or dict
+        列表2
+
+    Returns
+    ----------
     """
     assert type(l1) in {list, set, dict}
     assert type(l2) in {list, set, dict}
@@ -469,48 +528,16 @@ def union_set_num(l1, l2):
     return len(set(l1).union(set(l2)))
 
 
-def create_dir(path):
-    """
-    检查文件夹是否存在，如果存在则删除重新创建
-    :param path:    文件夹路径
-    :param type:    文件夹不存在是否报错  True报错， False不报错,并创建文件夹
-    :return:
-    """
-    if not os.path.exists(path):
-        os.makedirs(path)
-        return True
-    return False
-
-
-def del_dir(path):
-    """
-    删除目录
-    :param path:  路径
-    :return:
-    """
-    if os.path.exists(path):
-        shutil.rmtree(path)
-        return True
-    return False
-
-
-def del_file(path):
-    """
-    删除文件
-    :param path:  路径
-    :return:
-    """
-    if os.path.exists(path):
-        os.remove(path)
-        return True
-    return False
-
-
 def combin_dic(*args):
-    """
-    合并字典
-    :param args: 两个字典或多个
-    :return:
+    """combin_dic方法用于合并字典
+
+        Parameters
+        ----------
+        args : object
+            两个字典或多个
+
+        Returns
+        ----------
     """
     ret = {}
     if len(args) == 1:
@@ -527,11 +554,17 @@ def combin_dic(*args):
 
 
 def add_dic(dica, dicb):
-    """
-    字典累加
-    :param dica:   字典a
-    :param dicb:   字典b
-    :return:       字典累加
+    """add_dic方法用于字典累加,数字，字符累加
+
+        Parameters
+        ----------
+        dica : dict
+            字典a
+        dicb : dict
+            字典b
+
+        Returns
+        ----------
     """
     dic = {}
     for key in dica:
@@ -548,26 +581,43 @@ def add_dic(dica, dicb):
 
 
 def split_list(_list, slice):
-    """
-    拆分列表
-    :param _list:  列表
-    :param slice:  拆分块的大小
-    :return:       拆分后的列表
+    """split_list方法用于分割列表
+
+        Parameters
+        ----------
+        _list : list
+            列表
+        slice : int
+            拆分块的大小
+
+        Returns
+        ----------
     """
     return [_list[i:i + slice] for i in range(0, len(_list), slice)]
 
 
 def until(y=None, m=None, d=None, H=None, M=None, S=None, logger=None):
-    """
-    定时任务
-    :param y:  年
-    :param m:  月
-    :param d:  日
-    :param H:  时
-    :param M:  分
-    :param S:  秒
-    :param logger: 日志
-    :return:
+    """until方法用于定时任务
+
+        Parameters
+        ----------
+        y : int
+            年
+        m : int
+            月
+        d : int
+            日
+        H : int
+            时
+        M : int
+            分
+        S : int
+            秒
+        logger : object
+            日志
+
+        Returns
+        ----------
     """
     import time
     import datetime
@@ -663,12 +713,18 @@ def until(y=None, m=None, d=None, H=None, M=None, S=None, logger=None):
 
 
 def read(path, sep='\n', encoding='UTF-8'):
-    """
-    按行读数据
-    :param path: 路径
-    :param sep:  分隔符
-    :param encoding: 编码
-    :return:
+    """read方法用于按行读数据
+
+        Parameters
+        ----------
+        path : str
+            路径
+        sep : str
+            分隔符
+        encoding : str
+            编码
+        Returns
+        ----------
     """
     try:
         with open(path, 'r', encoding=encoding) as f:
@@ -704,11 +760,16 @@ def write(data, path, sep='\n', encoding='UTF-8'):
 
 
 def merge_commelement_list(lsts):
+    """merge_commelement_list方法用于把公共元素的列表合并，返回合并后的结果list
+
+    Parameters
+    ----------
+    lsts : list
+        列表数据
+    Returns
+    ----------
     """
-    把公共元素的列表合并，返回合并后的结果list
-    :param lsts:
-    :return:
-    """
+
     sets = [set(lst) for lst in lsts if lst]
     merged = 1
     while merged:
@@ -839,7 +900,7 @@ def iou(l1, l2):
 
 
 def list_to_dict(_list):
-    """list_to_dict方法用于列表转化为字典
+    """list_to_dict方法用于列表转化为字典[[key, val, val], [key, val, val]]
 
     Parameters
     ----------
@@ -888,48 +949,75 @@ def dict_to_list(_dict):
     return ret
 
 
-def write_yaml(data, path, encoding='UTF-8'):
-    """write_yaml方法用于写yaml配置文件
+# def write_yaml(data, path, encoding='UTF-8'):
+#     """write_yaml方法用于写yaml配置文件
+#
+#     Parameters
+#     ----------
+#     data : dict
+#         配置字典
+#     path : str
+#         保存路径
+#     encoding : str
+#         编码规则
+#
+#     Returns
+#     ----------
+#     """
+#     import yaml
+#     try:
+#         with open(path, 'w', encoding=encoding) as yaml_file:
+#             yaml.safe_dump(data, yaml_file)
+#     except:
+#         with open(path, 'w') as yaml_file:
+#             yaml.safe_dump(data, yaml_file)
+#
+#
+# def load_yaml(path, encoding='UTF-8'):
+#     """read_yaml方法用于读取yaml文件
+#
+#     Parameters
+#     ----------
+#     path : str
+#         yaml文件路径
+#     encoding : str
+#         编码规则
+#
+#     Returns
+#     ----------
+#     """
+#     import yaml
+#     try:
+#         with open(path, 'r', encoding=encoding) as f:
+#             config = yaml.load(f.read(), Loader=yaml.FullLoader)
+#     except:
+#         with open(path, 'r') as f:
+#             config = yaml.load(f.read())
+#     return config
+
+
+def show_memory(data, suffix='B'):
+    """show_memory方法用于查看变量占用内存多少
 
     Parameters
     ----------
-    data : dict
-        配置字典
-    path : str
-        保存路径
-    encoding : str
-        编码规则
-
+    data: object
+        数据对象
+    suffix: str
+        后缀
+        
     Returns
     ----------
     """
-    import yaml
-    try:
-        with open(path, 'w', encoding=encoding) as yaml_file:
-            yaml.safe_dump(data, yaml_file)
-    except:
-        with open(path, 'w') as yaml_file:
-            yaml.safe_dump(data, yaml_file)
+    num = sys.getsizeof(data)
+    for unit in ['', 'Ki', 'Mi', 'Gi', 'Ti', 'Pi', 'Ei', 'Zi']:
+        if abs(num) < 1024.0:
+            return "%3.1f %s%s" % (num, unit, suffix)
+        num /= 1024.0
+    return "%.1f %s%s" % (num, 'Yi', suffix)
 
 
-def load_yaml(path, encoding='UTF-8'):
-    """read_yaml方法用于读取yaml文件
-
-    Parameters
-    ----------
-    path : str
-        yaml文件路径
-    encoding : str
-        编码规则
-
-    Returns
-    ----------
+def get_pid():
+    """get_pid方法用于当前进程id
     """
-    import yaml
-    try:
-        with open(path, 'r', encoding=encoding) as f:
-            config = yaml.load(f.read(), Loader=yaml.FullLoader)
-    except:
-        with open(path, 'r') as f:
-            config = yaml.load(f.read())
-    return config
\ No newline at end of file
+    return os.getpid()
